==> aws-java-sdk-config-1.10.65-sources.jar: com/amazonaws/services/config/model/transform/ComplianceJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.config.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.config.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ComplianceMarshaller
 */
public class ComplianceJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(Compliance compliance, SdkJsonGenerator jsonGenerator) {
        if (compliance == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (compliance.getComplianceType() != null) {
                jsonGenerator.writeFieldName("ComplianceType").writeValue(
                        compliance.getComplianceType());
            }
            if (compliance.getComplianceContributorCount() != null) {
                jsonGenerator.writeFieldName("ComplianceContributorCount");
                ComplianceContributorCountJsonMarshaller.getInstance()
                        .marshall(compliance.getComplianceContributorCount(),
                                jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ComplianceJsonMarshaller instance;

    public static ComplianceJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ComplianceJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-config-1.10.66-sources.jar: com/amazonaws/services/config/model/transform/ComplianceJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.config.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.config.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * ComplianceMarshaller
 */
public class ComplianceJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(Compliance compliance,
            StructuredJsonGenerator jsonGenerator) {

        if (compliance == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (compliance.getComplianceType() != null) {
                jsonGenerator.writeFieldName("ComplianceType").writeValue(
                        compliance.getComplianceType());
            }
            if (compliance.getComplianceContributorCount() != null) {
                jsonGenerator.writeFieldName("ComplianceContributorCount");
                ComplianceContributorCountJsonMarshaller.getInstance()
                        .marshall(compliance.getComplianceContributorCount(),
                                jsonGenerator);
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ComplianceJsonMarshaller instance;

    public static ComplianceJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ComplianceJsonMarshaller();
        return instance;
    }

}
